slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSGHEP

Dense Generalized Hermitian Eigenvalue Problem.

### Notes

The problem is expressed as A*X = B*X*Lambda, where both A and B are real symmetric (or complex Hermitian) and B is positive-definite. Lambda is a diagonal matrix whose diagonal elements are the arguments of DSSolve(). After solve, A is overwritten with Lambda, and B is overwritten with I.

No intermediate state is implemented, nor compact storage.

### Used DS matrices

| DS_MAT_A | - first problem matrix
| DS_MAT_B | - second problem matrix
| DS_MAT_Q | - matrix of B-orthogonal eigenvectors, which is equal to X

### Implemented methods

| 0 | - Divide and Conquer (_sygvd)

### See Also

DSCreate(), DSSetType(), DSType

### Level

beginner

### Location

src/sys/classes/ds/impls/ghep/dsghep.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages